Doxy Build
==========

This repo contains build scripts for the Doxy system. At present, only LaTeX
is supported, via latexmk.

Installation
------------

To install, run::

  pip install doxybuild

Maintainers
-----------

* `Alex Thorne <mailto:alex@thorne.cc>`_
